> This is completely experimental work in progress / MVP at the moment. There will be bugs and no APIs are stable.

# `mrirage`

[![Build](https://github.com/cmi-dair/mrirage/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/cmi-dair/mrirage/actions/workflows/test.yml?query=branch%3Amaster)
[![codecov](https://codecov.io/gh/cmi-dair/mrirage/branch/master/graph/badge.svg?token=22HWWFWPW5)](https://codecov.io/gh/cmi-dair/mrirage)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![stability-wip](https://img.shields.io/badge/stability-work_in_progress-lightgrey.svg)
[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/cmi-dair/mrirage/blob/master/LICENSE)
[![pages](https://img.shields.io/badge/api-docs-blue)](https://cmi-dair.github.io/mrirage)

`mrirage` (pronounced _mirage_) is a scientific visualization library for Python
with the goal of creating and automating publication ready figures from 3D voxel MRI images.

## Features

- Highly customizable
- Declarative API
- Lightweight (only depends on common scientific Python packages)
- Custom voxel image slicing engine
- Custom layout and style systems built on `matplotlib`

## Tutorials

To get started [have a look at the tutorials](https://github.com/cmi-dair/mrirage/blob/master/examples/README.md).
